<?php

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * FriendFeed Posting Class
 *
 * Handles all the functions to tweet on twitter
 *
 * @package Social Auto Poster
 * @since 1.3.0
 */
class Wpw_Auto_Poster_FF_Posting {

	var $friendfeed, $model, $logs;
	
	public function __construct() {
	
		global $wpw_auto_poster_model,$wpw_auto_poster_logs;
		
		$this->model = $wpw_auto_poster_model;
		$this->logs	 = $wpw_auto_poster_logs;
	}
	
	/**
	 * Include FriendFeed Class
	 * 
	 * Handles to load friendfeed class
	 * 
	 * @package Social Auto Poster
 	 * @since 1.3.0
	 */
	public function wpw_auto_poster_load_friendfeed() {
		
		global $wpw_auto_poster_options;

		//friendfeed declaration
		if( !empty( $wpw_auto_poster_options['friendfeed_nickname'] ) && !empty( $wpw_auto_poster_options['friendfeed_remote_key'] ) ) {

			if( !class_exists( 'FriendFeed' ) ) {
				require_once( WPW_AUTO_POSTER_SOCIAL_DIR . '/friendfeed/friendfeed.php' );
			}
			
			// FriendFeed Object
			$this->friendfeed = new FriendFeed( WPW_AUTO_POSTER_FF_NICKNAME, WPW_AUTO_POSTER_FF_REMOTE_KEY );
			
			return true;
			
		} else {
			
			return false;	
		}
		
	}
	
	/**
	 * Post To FriendFeed
	 * 
	 * Handles to Post on FriendFeed account
	 * 
	 * @package Social Auto Poster
	 * @since 1.3.0
	 */
	public function wpw_auto_poster_post_to_friendfeed( $post ) {
		
		global $wpw_auto_poster_options;
		
		//load friendfeed class
		$friendfeed = $this->wpw_auto_poster_load_friendfeed();
		
		//check linkedin loaded or not
		if( !$friendfeed ) return false;
		
		//posting logs data
		$posting_logs_data = array();
		
		//record logs for delicious posting
		$this->logs->wpw_auto_poster_add( 'FriendFeed posting to user account begins.' );
		
		//record logs for friendfeed nickname and remote key
		$this->logs->wpw_auto_poster_add( 'FriendFeed Nckname : ' . WPW_AUTO_POSTER_FF_NICKNAME );
		$this->logs->wpw_auto_poster_add( 'FriendFeed Remote Key : ' . WPW_AUTO_POSTER_FF_REMOTE_KEY );
		
		//meta prefix
		$prefix = WPW_AUTO_POSTER_META_PREFIX;
		
		$unique = 'false';
		$userdata = get_userdata( $post->post_author );
		$first_name = $userdata->first_name; //user first name
		$last_name = $userdata->last_name; //user last name
		
		//published status
		$ispublished = get_post_meta( $post->ID, $prefix. 'ff_status', true );
		
		//post title
		$posttitle = $post->post_title;
		$customtitle = get_post_meta( $post->ID, $prefix. 'ff_post_title', true );
		$title = !empty( $customtitle ) ? $customtitle : $posttitle;
		
		//post link
		$wpw_auto_poster_ff_custom_link 	= get_post_meta( $post->ID, $prefix . 'ff_custom_post_link', true );
		
		//if post is published on friendfeed once then change url to prevent duplication
		if( isset( $ispublished ) && $ispublished == '1' ) { 
			$unique = 'true';
		}
	
		//post link for posting to friendfeed user wall
		$postlink = isset( $wpw_auto_poster_ff_custom_link ) && !empty( $wpw_auto_poster_ff_custom_link ) ? $wpw_auto_poster_ff_custom_link : '';
		//if custom link is set or not
		$customlink = !empty( $postlink ) ? 'true' : 'false';
				
		//do url in shortner form when shortner format is not set wordpress
		$postlink = $this->model->wpw_auto_poster_get_short_post_link( $postlink, $unique, $post->ID, $customlink, 'ff' );
		
		//post image
		$postimage = get_post_meta( $post->ID, $prefix.'ff_post_image', true );
		
		/**************
		 * Image Priority
		 * If metabox image set then take from metabox
		 * If metabox image is not set then take from featured image
		 * If featured image is not set then take from settings page
		 **************/
		
		//get featured image from post / page / custom post type
		$post_featured_img = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );
		//check custom image is set in meta and not empty
		if( isset( $postimage['src'] ) && !empty( $postimage['src'] ) ) {
			$postimage = $postimage['src'];
		} elseif ( isset( $post_featured_img[0] ) && !empty( $post_featured_img[0] ) ) {
			//check post featrued image is set the use that image
			$postimage = $post_featured_img[0];
		} else {
			//else get post image from settings page
			$postimage = $wpw_auto_poster_options['ff_post_img'];
		}
		
		//comments
		$comments = get_post_meta( $post->ID, $prefix.'ff_post_comment', true );
		$comments = !empty( $comments ) ? $comments : strip_shortcodes( $post->post_content );
		
		//strip html kses and tags
		$comments = $this->model->wpw_auto_poster_stripslashes_deep( $comments );
		//decode html
		$comments = $this->model->wpw_auto_poster_html_decode( $comments );
		
		$search_arr = array( '{title}', '{link}', '{first_name}' , '{last_name}', '{sitename}' );
		$replace_arr = array( $title, $postlink, $first_name, $last_name, get_option( 'blogname') );
		$comments = str_replace( $search_arr, $replace_arr, $comments ); 	
		
		$friendfeeddata = array(
								'posttitle'		=>	$title, 
								'postlink' 		=>	$postlink,
								'comments'		=>	$comments,
								'image' 		=>	$postimage
							);
							
		//posting logs data
		$posting_logs_data = array(	
										'title' 	=> $title,
										'content' 	=> $comments,
										'link' 		=> $postlink,
										'image' 	=> $postimage
									);
									
		//record logs for friendfeed data
		$this->logs->wpw_auto_poster_add( 'FriendFeed post data : ' . var_export( $friendfeeddata, true ) );
		
		$code = $this->friendfeed->publish_link( $title, $postlink, $comments, (array) $postimage );
		
		//check id is set in result data and not empty
		if( isset( $code->id ) && !empty( $code->id ) ) {
			
			$user_name = isset( $code->user->nickname ) ? $code->user->nickname : '';
			
			//User details
			$posting_logs_user_details = array(
													'account_id' 			=> isset( $code->user->id ) ? $code->user->id : '',
													'display_name'			=> isset( $code->user->name ) ? $code->user->name . ' (' . $user_name . ')' : '',
													'user_name'				=> $user_name,
													'profile_url'			=> isset( $code->user->profileUrl ) ? $code->user->profileUrl : '',
													'friendfeed_nickname' 	=> WPW_AUTO_POSTER_FF_NICKNAME,
													'friendfeed_remote_key'	=> WPW_AUTO_POSTER_FF_REMOTE_KEY
												);
			
			//posting logs store into database
			$this->model->wpw_auto_poster_insert_posting_log( $post->ID, 'ff', $posting_logs_data, $posting_logs_user_details );
			
			//record logs for post posted to friendfeed
			$this->logs->wpw_auto_poster_add( 'FriendFeed posted to user account : Response ID ' . $code->id );
			
		} else {
			//record logs for post posting frienfeed failed
			$this->logs->wpw_auto_poster_add( 'Problem to post on FriendFeed ');
		}
		
		return $code;
	}
	
	/**
	 * FriendFeed Posting
	 * 
	 * Handles to friendfeed posting
	 * by post data
	 * 
	 * @package Social Auto Poster
 	 * @since 1.5.0
	 */
	public function wpw_auto_poster_ff_posting( $post ) {
		
		global $wpw_auto_poster_options;
		
		$prefix = WPW_AUTO_POSTER_META_PREFIX;

		//record logs for friendfeed is enable for posting
		$this->logs->wpw_auto_poster_add( 'Posting is enabled' );
					
		$res = $this->wpw_auto_poster_post_to_friendfeed( $post );
		
		if( isset( $res->id ) && !empty( $res->id ) ) {
			
			//record logs for posting done on friendfeed
			$this->logs->wpw_auto_poster_add( 'FriendFeed posting completed successfully.' );
			
			update_post_meta( $post->ID, $prefix . 'ff_status', '1' );
			return true;
		}
		return false;
	}
}
?>